==> ejc-probudget-api-3.0.0-20210910.031812-16-sources.jar: com/ejianc/business/budget/vo/BudgetChangeVO.java <==
package com.ejianc.business.budget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 预算变更
 *
 * @author generator
 *
 */
public class BudgetChangeVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long budgetId; // 预算ID
    private String billCode; // 变更编号
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private java.util.Date changeDate; // 变更日期
    private java.math.BigDecimal baseIncomebudgetMny; // 初始收入预算金额
    private java.math.BigDecimal beforeIncomebudgetMny; // 变更前收入预算金额
    private java.math.BigDecimal incomebudgetMny; // 收入预算金额
    private java.math.BigDecimal changingIncomebudgetMny; // 变更中收入预算金额
    private java.math.BigDecimal baseCostbudgetMny; // 初始成本预算金额
    private java.math.BigDecimal beforeCostbudgetMny; // 变更前成本预算金额
    private java.math.BigDecimal costbudgetMny; // 成本预算金额
    private java.math.BigDecimal changingCostbudgetMny; // 变更中成本预算金额
    private java.math.BigDecimal baseLaborMny; // 初始人工费
    private java.math.BigDecimal beforeLaborMny; // 变更前人工费
    private java.math.BigDecimal laborMny; // 人工费
    private java.math.BigDecimal changingLaborMny; // 变更中人工费
    private java.math.BigDecimal baseMaterialMny; // 初始材料费
    private java.math.BigDecimal beforeMaterialMny; // 变更前材料费
    private java.math.BigDecimal materialMny; // 材料费
    private java.math.BigDecimal changingMaterialMny; // 变更中材料费
    private java.math.BigDecimal baseManageRate; // 初始管理费率
    private java.math.BigDecimal beforeManageRate; // 变更前管理费率
    private java.math.BigDecimal manageRate; // 管理费率
    private java.math.BigDecimal changingManageRate; // 变更中管理费率
    private java.math.BigDecimal baseManageMny; // 初始管理费
    private java.math.BigDecimal beforeManageMny; // 变更前管理费
    private java.math.BigDecimal manageMny; // 管理费
    private java.math.BigDecimal changingManageMny; // 变更中管理费
    private java.math.BigDecimal baseIncomebudgetAdjustMny; // 初始收入预算调整金额
    private java.math.BigDecimal beforeIncomebudgetAdjustMny; // 变更前收入预算调整金额
    private java.math.BigDecimal incomebudgetAdjustMny; // 收入预算调整金额
    private java.math.BigDecimal changingIncomebudgetAdjustMny; // 变更中收入预算调整金额
    private String memo; // 备注
    private String changeReason; // 变更原因
    private java.util.Date usedTime; // 生效时间
    private Integer billState; // 单据状态（审批必须字段）
    private Integer changeVersion; // 变更版本
    private String area; //所属区域


    /**
     * 预算ID
     */
    public Long getBudgetId() {
        return budgetId;
    }

    /**
     * 预算ID
     */
    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }
    /**
     * 变更编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 变更编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 变更日期
     */
    public java.util.Date getChangeDate() {
        return changeDate;
    }

    /**
     * 变更日期
     */
    public void setChangeDate(java.util.Date changeDate) {
        this.changeDate = changeDate;
    }
    /**
     * 初始收入预算金额
     */
    public java.math.BigDecimal getBaseIncomebudgetMny() {
        return baseIncomebudgetMny;
    }

    /**
     * 初始收入预算金额
     */
    public void setBaseIncomebudgetMny(java.math.BigDecimal baseIncomebudgetMny) {
        this.baseIncomebudgetMny = baseIncomebudgetMny;
    }
    /**
     * 变更前收入预算金额
     */
    public java.math.BigDecimal getBeforeIncomebudgetMny() {
        return beforeIncomebudgetMny;
    }

    /**
     * 变更前收入预算金额
     */
    public void setBeforeIncomebudgetMny(java.math.BigDecimal beforeIncomebudgetMny) {
        this.beforeIncomebudgetMny = beforeIncomebudgetMny;
    }
    /**
     * 收入预算金额
     */
    public java.math.BigDecimal getIncomebudgetMny() {
        return incomebudgetMny;
    }

    /**
     * 收入预算金额
     */
    public void setIncomebudgetMny(java.math.BigDecimal incomebudgetMny) {
        this.incomebudgetMny = incomebudgetMny;
    }
    /**
     * 变更中收入预算金额
     */
    public java.math.BigDecimal getChangingIncomebudgetMny() {
        return changingIncomebudgetMny;
    }

    /**
     * 变更中收入预算金额
     */
    public void setChangingIncomebudgetMny(java.math.BigDecimal changingIncomebudgetMny) {
        this.changingIncomebudgetMny = changingIncomebudgetMny;
    }
    /**
     * 初始成本预算金额
     */
    public java.math.BigDecimal getBaseCostbudgetMny() {
        return baseCostbudgetMny;
    }

    /**
     * 初始成本预算金额
     */
    public void setBaseCostbudgetMny(java.math.BigDecimal baseCostbudgetMny) {
        this.baseCostbudgetMny = baseCostbudgetMny;
    }
    /**
     * 变更前成本预算金额
     */
    public java.math.BigDecimal getBeforeCostbudgetMny() {
        return beforeCostbudgetMny;
    }

    /**
     * 变更前成本预算金额
     */
    public void setBeforeCostbudgetMny(java.math.BigDecimal beforeCostbudgetMny) {
        this.beforeCostbudgetMny = beforeCostbudgetMny;
    }
    /**
     * 成本预算金额
     */
    public java.math.BigDecimal getCostbudgetMny() {
        return costbudgetMny;
    }

    /**
     * 成本预算金额
     */
    public void setCostbudgetMny(java.math.BigDecimal costbudgetMny) {
        this.costbudgetMny = costbudgetMny;
    }
    /**
     * 变更中成本预算金额
     */
    public java.math.BigDecimal getChangingCostbudgetMny() {
        return changingCostbudgetMny;
    }

    /**
     * 变更中成本预算金额
     */
    public void setChangingCostbudgetMny(java.math.BigDecimal changingCostbudgetMny) {
        this.changingCostbudgetMny = changingCostbudgetMny;
    }
    /**
     * 初始人工费
     */
    public java.math.BigDecimal getBaseLaborMny() {
        return baseLaborMny;
    }

    /**
     * 初始人工费
     */
    public void setBaseLaborMny(java.math.BigDecimal baseLaborMny) {
        this.baseLaborMny = baseLaborMny;
    }
    /**
     * 变更前人工费
     */
    public java.math.BigDecimal getBeforeLaborMny() {
        return beforeLaborMny;
    }

    /**
     * 变更前人工费
     */
    public void setBeforeLaborMny(java.math.BigDecimal beforeLaborMny) {
        this.beforeLaborMny = beforeLaborMny;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getLaborMny() {
        return laborMny;
    }

    /**
     * 人工费
     */
    public void setLaborMny(java.math.BigDecimal laborMny) {
        this.laborMny = laborMny;
    }
    /**
     * 变更中人工费
     */
    public java.math.BigDecimal getChangingLaborMny() {
        return changingLaborMny;
    }

    /**
     * 变更中人工费
     */
    public void setChangingLaborMny(java.math.BigDecimal changingLaborMny) {
        this.changingLaborMny = changingLaborMny;
    }
    /**
     * 初始材料费
     */
    public java.math.BigDecimal getBaseMaterialMny() {
        return baseMaterialMny;
    }

    /**
     * 初始材料费
     */
    public void setBaseMaterialMny(java.math.BigDecimal baseMaterialMny) {
        this.baseMaterialMny = baseMaterialMny;
    }
    /**
     * 变更前材料费
     */
    public java.math.BigDecimal getBeforeMaterialMny() {
        return beforeMaterialMny;
    }

    /**
     * 变更前材料费
     */
    public void setBeforeMaterialMny(java.math.BigDecimal beforeMaterialMny) {
        this.beforeMaterialMny = beforeMaterialMny;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialMny() {
        return materialMny;
    }

    /**
     * 材料费
     */
    public void setMaterialMny(java.math.BigDecimal materialMny) {
        this.materialMny = materialMny;
    }
    /**
     * 变更中材料费
     */
    public java.math.BigDecimal getChangingMaterialMny() {
        return changingMaterialMny;
    }

    /**
     * 变更中材料费
     */
    public void setChangingMaterialMny(java.math.BigDecimal changingMaterialMny) {
        this.changingMaterialMny = changingMaterialMny;
    }
    /**
     * 初始管理费率
     */
    public java.math.BigDecimal getBaseManageRate() {
        return baseManageRate;
    }

    /**
     * 初始管理费率
     */
    public void setBaseManageRate(java.math.BigDecimal baseManageRate) {
        this.baseManageRate = baseManageRate;
    }
    /**
     * 变更前管理费率
     */
    public java.math.BigDecimal getBeforeManageRate() {
        return beforeManageRate;
    }

    /**
     * 变更前管理费率
     */
    public void setBeforeManageRate(java.math.BigDecimal beforeManageRate) {
        this.beforeManageRate = beforeManageRate;
    }
    /**
     * 管理费率
     */
    public java.math.BigDecimal getManageRate() {
        return manageRate;
    }

    /**
     * 管理费率
     */
    public void setManageRate(java.math.BigDecimal manageRate) {
        this.manageRate = manageRate;
    }
    /**
     * 变更中管理费率
     */
    public java.math.BigDecimal getChangingManageRate() {
        return changingManageRate;
    }

    /**
     * 变更中管理费率
     */
    public void setChangingManageRate(java.math.BigDecimal changingManageRate) {
        this.changingManageRate = changingManageRate;
    }
    /**
     * 初始管理费
     */
    public java.math.BigDecimal getBaseManageMny() {
        return baseManageMny;
    }

    /**
     * 初始管理费
     */
    public void setBaseManageMny(java.math.BigDecimal baseManageMny) {
        this.baseManageMny = baseManageMny;
    }
    /**
     * 变更前管理费
     */
    public java.math.BigDecimal getBeforeManageMny() {
        return beforeManageMny;
    }

    /**
     * 变更前管理费
     */
    public void setBeforeManageMny(java.math.BigDecimal beforeManageMny) {
        this.beforeManageMny = beforeManageMny;
    }
    /**
     * 管理费
     */
    public java.math.BigDecimal getManageMny() {
        return manageMny;
    }

    /**
     * 管理费
     */
    public void setManageMny(java.math.BigDecimal manageMny) {
        this.manageMny = manageMny;
    }
    /**
     * 变更中管理费
     */
    public java.math.BigDecimal getChangingManageMny() {
        return changingManageMny;
    }

    /**
     * 变更中管理费
     */
    public void setChangingManageMny(java.math.BigDecimal changingManageMny) {
        this.changingManageMny = changingManageMny;
    }
    /**
     * 初始收入预算调整金额
     */
    public java.math.BigDecimal getBaseIncomebudgetAdjustMny() {
        return baseIncomebudgetAdjustMny;
    }

    /**
     * 初始收入预算调整金额
     */
    public void setBaseIncomebudgetAdjustMny(java.math.BigDecimal baseIncomebudgetAdjustMny) {
        this.baseIncomebudgetAdjustMny = baseIncomebudgetAdjustMny;
    }
    /**
     * 变更前收入预算调整金额
     */
    public java.math.BigDecimal getBeforeIncomebudgetAdjustMny() {
        return beforeIncomebudgetAdjustMny;
    }

    /**
     * 变更前收入预算调整金额
     */
    public void setBeforeIncomebudgetAdjustMny(java.math.BigDecimal beforeIncomebudgetAdjustMny) {
        this.beforeIncomebudgetAdjustMny = beforeIncomebudgetAdjustMny;
    }
    /**
     * 收入预算调整金额
     */
    public java.math.BigDecimal getIncomebudgetAdjustMny() {
        return incomebudgetAdjustMny;
    }

    /**
     * 收入预算调整金额
     */
    public void setIncomebudgetAdjustMny(java.math.BigDecimal incomebudgetAdjustMny) {
        this.incomebudgetAdjustMny = incomebudgetAdjustMny;
    }
    /**
     * 变更中收入预算调整金额
     */
    public java.math.BigDecimal getChangingIncomebudgetAdjustMny() {
        return changingIncomebudgetAdjustMny;
    }

    /**
     * 变更中收入预算调整金额
     */
    public void setChangingIncomebudgetAdjustMny(java.math.BigDecimal changingIncomebudgetAdjustMny) {
        this.changingIncomebudgetAdjustMny = changingIncomebudgetAdjustMny;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 变更原因
     */
    public String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getUsedTime() {
        return usedTime;
    }

    /**
     * 生效时间
     */
    public void setUsedTime(java.util.Date usedTime) {
        this.usedTime = usedTime;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更版本
     */
    public Integer getChangeVersion() {
        return changeVersion;
    }

    /**
     * 变更版本
     */
    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }

    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
}

==> ejc-probudget-api-3.0.0-20210916.062836-46-sources.jar: com/ejianc/business/budget/vo/BudgetChangeVO.java <==
package com.ejianc.business.budget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 预算变更
 *
 * @author generator
 *
 */
public class BudgetChangeVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long budgetId; // 预算ID
    private String billCode; // 变更编号
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private java.util.Date changeDate; // 变更日期
    private java.math.BigDecimal baseIncomebudgetMny; // 初始收入预算金额
    private java.math.BigDecimal beforeIncomebudgetMny; // 变更前收入预算金额
    private java.math.BigDecimal incomebudgetMny; // 收入预算金额
    private java.math.BigDecimal changingIncomebudgetMny; // 变更中收入预算金额
    private java.math.BigDecimal baseCostbudgetMny; // 初始成本预算金额
    private java.math.BigDecimal beforeCostbudgetMny; // 变更前成本预算金额
    private java.math.BigDecimal costbudgetMny; // 成本预算金额
    private java.math.BigDecimal changingCostbudgetMny; // 变更中成本预算金额
    private java.math.BigDecimal baseLaborMny; // 初始人工费
    private java.math.BigDecimal beforeLaborMny; // 变更前人工费
    private java.math.BigDecimal laborMny; // 人工费
    private java.math.BigDecimal changingLaborMny; // 变更中人工费
    private java.math.BigDecimal baseMaterialMny; // 初始材料费
    private java.math.BigDecimal beforeMaterialMny; // 变更前材料费
    private java.math.BigDecimal materialMny; // 材料费
    private java.math.BigDecimal changingMaterialMny; // 变更中材料费
    private java.math.BigDecimal baseManageRate; // 初始管理费率
    private java.math.BigDecimal beforeManageRate; // 变更前管理费率
    private java.math.BigDecimal manageRate; // 管理费率
    private java.math.BigDecimal changingManageRate; // 变更中管理费率
    private java.math.BigDecimal baseManageMny; // 初始管理费
    private java.math.BigDecimal beforeManageMny; // 变更前管理费
    private java.math.BigDecimal manageMny; // 管理费
    private java.math.BigDecimal changingManageMny; // 变更中管理费
    private java.math.BigDecimal baseIncomebudgetAdjustMny; // 初始收入预算调整金额
    private java.math.BigDecimal beforeIncomebudgetAdjustMny; // 变更前收入预算调整金额
    private java.math.BigDecimal incomebudgetAdjustMny; // 收入预算调整金额
    private java.math.BigDecimal changingIncomebudgetAdjustMny; // 变更中收入预算调整金额
    private String memo; // 备注
    private String changeReason; // 变更原因
    private java.util.Date usedTime; // 生效时间
    private Integer billState; // 单据状态（审批必须字段）
    private Integer changeVersion; // 变更版本
    private String area; //所属区域

    private List<BudgetChangeDetailVO> detailList = new ArrayList<>(); // 预算管理明细

    /**
     * 预算ID
     */
    public Long getBudgetId() {
        return budgetId;
    }

    /**
     * 预算ID
     */
    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }
    /**
     * 变更编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 变更编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 变更日期
     */
    public java.util.Date getChangeDate() {
        return changeDate;
    }

    /**
     * 变更日期
     */
    public void setChangeDate(java.util.Date changeDate) {
        this.changeDate = changeDate;
    }
    /**
     * 初始收入预算金额
     */
    public java.math.BigDecimal getBaseIncomebudgetMny() {
        return baseIncomebudgetMny;
    }

    /**
     * 初始收入预算金额
     */
    public void setBaseIncomebudgetMny(java.math.BigDecimal baseIncomebudgetMny) {
        this.baseIncomebudgetMny = baseIncomebudgetMny;
    }
    /**
     * 变更前收入预算金额
     */
    public java.math.BigDecimal getBeforeIncomebudgetMny() {
        return beforeIncomebudgetMny;
    }

    /**
     * 变更前收入预算金额
     */
    public void setBeforeIncomebudgetMny(java.math.BigDecimal beforeIncomebudgetMny) {
        this.beforeIncomebudgetMny = beforeIncomebudgetMny;
    }
    /**
     * 收入预算金额
     */
    public java.math.BigDecimal getIncomebudgetMny() {
        return incomebudgetMny;
    }

    /**
     * 收入预算金额
     */
    public void setIncomebudgetMny(java.math.BigDecimal incomebudgetMny) {
        this.incomebudgetMny = incomebudgetMny;
    }
    /**
     * 变更中收入预算金额
     */
    public java.math.BigDecimal getChangingIncomebudgetMny() {
        return changingIncomebudgetMny;
    }

    /**
     * 变更中收入预算金额
     */
    public void setChangingIncomebudgetMny(java.math.BigDecimal changingIncomebudgetMny) {
        this.changingIncomebudgetMny = changingIncomebudgetMny;
    }
    /**
     * 初始成本预算金额
     */
    public java.math.BigDecimal getBaseCostbudgetMny() {
        return baseCostbudgetMny;
    }

    /**
     * 初始成本预算金额
     */
    public void setBaseCostbudgetMny(java.math.BigDecimal baseCostbudgetMny) {
        this.baseCostbudgetMny = baseCostbudgetMny;
    }
    /**
     * 变更前成本预算金额
     */
    public java.math.BigDecimal getBeforeCostbudgetMny() {
        return beforeCostbudgetMny;
    }

    /**
     * 变更前成本预算金额
     */
    public void setBeforeCostbudgetMny(java.math.BigDecimal beforeCostbudgetMny) {
        this.beforeCostbudgetMny = beforeCostbudgetMny;
    }
    /**
     * 成本预算金额
     */
    public java.math.BigDecimal getCostbudgetMny() {
        return costbudgetMny;
    }

    /**
     * 成本预算金额
     */
    public void setCostbudgetMny(java.math.BigDecimal costbudgetMny) {
        this.costbudgetMny = costbudgetMny;
    }
    /**
     * 变更中成本预算金额
     */
    public java.math.BigDecimal getChangingCostbudgetMny() {
        return changingCostbudgetMny;
    }

    /**
     * 变更中成本预算金额
     */
    public void setChangingCostbudgetMny(java.math.BigDecimal changingCostbudgetMny) {
        this.changingCostbudgetMny = changingCostbudgetMny;
    }
    /**
     * 初始人工费
     */
    public java.math.BigDecimal getBaseLaborMny() {
        return baseLaborMny;
    }

    /**
     * 初始人工费
     */
    public void setBaseLaborMny(java.math.BigDecimal baseLaborMny) {
        this.baseLaborMny = baseLaborMny;
    }
    /**
     * 变更前人工费
     */
    public java.math.BigDecimal getBeforeLaborMny() {
        return beforeLaborMny;
    }

    /**
     * 变更前人工费
     */
    public void setBeforeLaborMny(java.math.BigDecimal beforeLaborMny) {
        this.beforeLaborMny = beforeLaborMny;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getLaborMny() {
        return laborMny;
    }

    /**
     * 人工费
     */
    public void setLaborMny(java.math.BigDecimal laborMny) {
        this.laborMny = laborMny;
    }
    /**
     * 变更中人工费
     */
    public java.math.BigDecimal getChangingLaborMny() {
        return changingLaborMny;
    }

    /**
     * 变更中人工费
     */
    public void setChangingLaborMny(java.math.BigDecimal changingLaborMny) {
        this.changingLaborMny = changingLaborMny;
    }
    /**
     * 初始材料费
     */
    public java.math.BigDecimal getBaseMaterialMny() {
        return baseMaterialMny;
    }

    /**
     * 初始材料费
     */
    public void setBaseMaterialMny(java.math.BigDecimal baseMaterialMny) {
        this.baseMaterialMny = baseMaterialMny;
    }
    /**
     * 变更前材料费
     */
    public java.math.BigDecimal getBeforeMaterialMny() {
        return beforeMaterialMny;
    }

    /**
     * 变更前材料费
     */
    public void setBeforeMaterialMny(java.math.BigDecimal beforeMaterialMny) {
        this.beforeMaterialMny = beforeMaterialMny;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialMny() {
        return materialMny;
    }

    /**
     * 材料费
     */
    public void setMaterialMny(java.math.BigDecimal materialMny) {
        this.materialMny = materialMny;
    }
    /**
     * 变更中材料费
     */
    public java.math.BigDecimal getChangingMaterialMny() {
        return changingMaterialMny;
    }

    /**
     * 变更中材料费
     */
    public void setChangingMaterialMny(java.math.BigDecimal changingMaterialMny) {
        this.changingMaterialMny = changingMaterialMny;
    }
    /**
     * 初始管理费率
     */
    public java.math.BigDecimal getBaseManageRate() {
        return baseManageRate;
    }

    /**
     * 初始管理费率
     */
    public void setBaseManageRate(java.math.BigDecimal baseManageRate) {
        this.baseManageRate = baseManageRate;
    }
    /**
     * 变更前管理费率
     */
    public java.math.BigDecimal getBeforeManageRate() {
        return beforeManageRate;
    }

    /**
     * 变更前管理费率
     */
    public void setBeforeManageRate(java.math.BigDecimal beforeManageRate) {
        this.beforeManageRate = beforeManageRate;
    }
    /**
     * 管理费率
     */
    public java.math.BigDecimal getManageRate() {
        return manageRate;
    }

    /**
     * 管理费率
     */
    public void setManageRate(java.math.BigDecimal manageRate) {
        this.manageRate = manageRate;
    }
    /**
     * 变更中管理费率
     */
    public java.math.BigDecimal getChangingManageRate() {
        return changingManageRate;
    }

    /**
     * 变更中管理费率
     */
    public void setChangingManageRate(java.math.BigDecimal changingManageRate) {
        this.changingManageRate = changingManageRate;
    }
    /**
     * 初始管理费
     */
    public java.math.BigDecimal getBaseManageMny() {
        return baseManageMny;
    }

    /**
     * 初始管理费
     */
    public void setBaseManageMny(java.math.BigDecimal baseManageMny) {
        this.baseManageMny = baseManageMny;
    }
    /**
     * 变更前管理费
     */
    public java.math.BigDecimal getBeforeManageMny() {
        return beforeManageMny;
    }

    /**
     * 变更前管理费
     */
    public void setBeforeManageMny(java.math.BigDecimal beforeManageMny) {
        this.beforeManageMny = beforeManageMny;
    }
    /**
     * 管理费
     */
    public java.math.BigDecimal getManageMny() {
        return manageMny;
    }

    /**
     * 管理费
     */
    public void setManageMny(java.math.BigDecimal manageMny) {
        this.manageMny = manageMny;
    }
    /**
     * 变更中管理费
     */
    public java.math.BigDecimal getChangingManageMny() {
        return changingManageMny;
    }

    /**
     * 变更中管理费
     */
    public void setChangingManageMny(java.math.BigDecimal changingManageMny) {
        this.changingManageMny = changingManageMny;
    }
    /**
     * 初始收入预算调整金额
     */
    public java.math.BigDecimal getBaseIncomebudgetAdjustMny() {
        return baseIncomebudgetAdjustMny;
    }

    /**
     * 初始收入预算调整金额
     */
    public void setBaseIncomebudgetAdjustMny(java.math.BigDecimal baseIncomebudgetAdjustMny) {
        this.baseIncomebudgetAdjustMny = baseIncomebudgetAdjustMny;
    }
    /**
     * 变更前收入预算调整金额
     */
    public java.math.BigDecimal getBeforeIncomebudgetAdjustMny() {
        return beforeIncomebudgetAdjustMny;
    }

    /**
     * 变更前收入预算调整金额
     */
    public void setBeforeIncomebudgetAdjustMny(java.math.BigDecimal beforeIncomebudgetAdjustMny) {
        this.beforeIncomebudgetAdjustMny = beforeIncomebudgetAdjustMny;
    }
    /**
     * 收入预算调整金额
     */
    public java.math.BigDecimal getIncomebudgetAdjustMny() {
        return incomebudgetAdjustMny;
    }

    /**
     * 收入预算调整金额
     */
    public void setIncomebudgetAdjustMny(java.math.BigDecimal incomebudgetAdjustMny) {
        this.incomebudgetAdjustMny = incomebudgetAdjustMny;
    }
    /**
     * 变更中收入预算调整金额
     */
    public java.math.BigDecimal getChangingIncomebudgetAdjustMny() {
        return changingIncomebudgetAdjustMny;
    }

    /**
     * 变更中收入预算调整金额
     */
    public void setChangingIncomebudgetAdjustMny(java.math.BigDecimal changingIncomebudgetAdjustMny) {
        this.changingIncomebudgetAdjustMny = changingIncomebudgetAdjustMny;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 变更原因
     */
    public String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getUsedTime() {
        return usedTime;
    }

    /**
     * 生效时间
     */
    public void setUsedTime(java.util.Date usedTime) {
        this.usedTime = usedTime;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更版本
     */
    public Integer getChangeVersion() {
        return changeVersion;
    }

    /**
     * 变更版本
     */
    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }

    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }

    public List<BudgetChangeDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<BudgetChangeDetailVO> detailList) {
        this.detailList = detailList;
    }
}
